@@ -8,7 +8,7 @@ from serverly.utils import *
 
 from fileloghelper import Logger
 
-version = "0.0.9"
+version = "0.0.11"
 description = "A really simple-to-use HTTP-server"
 address = ("localhost", 8080)
 name = "PyServer"
@@ -17,12 +17,12 @@ logger = Logger("serverly.log", "serverly", False, False)
 
 class Handler(BaseHTTPRequestHandler):
     def do_GET(self):
-        logger.set_context(name + ": GET")
         parsed_url = parse.urlparse(self.path)
         response_code, content, info = _sitemap.get_content(
             "GET", parsed_url.path)
+        logger.set_context(name + ": GET")
         logger.debug(
-            f"\nresponse_code: {response_code}\ninfo: {info}\ncontent: {content}")
+            f"Sent {str(response_code)}, path {parsed_url.path} (GET)")
         self.send_response(response_code)
         for key, value in info.items():
             self.send_header(key, value)
@@ -30,14 +30,14 @@ class Handler(BaseHTTPRequestHandler):
         self.wfile.write(bytes(content, "utf-8"))
 
     def do_POST(self):
-        logger.set_context(name + ": POST")
         parsed_url = parse.urlparse(self.path)
         length = int(self.headers.get("Content-Length", 0))
         data = str(self.rfile.read(length), "utf-8")
         response_code, content, info = _sitemap.get_content(
             "POST", parsed_url.path, data)
+        logger.set_context(name + ": POST")
         logger.debug(
-            f"POST\ncode: {response_code}\ninfo: {info}\ncontent: {content}")
+            f"Sent {str(response_code)}, path {parsed_url.path} (POST)")
         self.send_response(response_code)
         for key, value in info.items():
             self.send_header(key, value)
@@ -62,8 +62,8 @@ class Server:
         logger.set_context("startup")
         logger.success("Server initialized", False)
 
-    @classmethod
-    def _get_server_address(cls, address):
+    @staticmethod
+    def _get_server_address(address):
         """returns tupe[str, int], e.g. ('localhost', 8080)"""
         hostname = ""
         port = 0
@@ -125,7 +125,7 @@ class StaticSite:
 
     def get_content(self):
         content = ""
-        if self.path == "^error$" or self.path == "none" or self.file_path == "^error$" or self.file_path == "none":
+        if self.path == "^/error$" or self.path == "none" or self.file_path == "^/error$" or self.file_path == "none":
             content = "<html><head><title>Error</title></head><body><h1>An error occured.</h1></body></html>"
         else:
             with open(self.file_path, "r") as f:
@@ -134,7 +134,15 @@ class StaticSite:
 
 
 class Sitemap:
-    def __init__(self, superpath: str = "/", error_page=None):
+    def __init__(self, superpath: str = "/", error_page: StaticSite = None):
+        """
+        Create a new Sitemap instance
+        :param superpath: path which will replace every occurence of '/SUPERPATH/' or 'SUPERPATH/'. Great for accessing multiple servers from one domain and forwarding the requests to this server.
+        :param error_page: default error page
+
+        :type superpath: str
+        :type error_page: StaticPage
+        """
         check_relative_path(superpath)
         self.superpath = superpath
         self.methods = {
@@ -142,7 +150,7 @@ class Sitemap:
             "post": {}
         }
         if error_page == None:
-            self.error_page = StaticSite("error", "none")
+            self.error_page = StaticSite("/error", "none")
         elif issubclass(error_page.__class__, StaticSite):
             self.error_page = error_page
         else:
@@ -168,6 +176,26 @@ class Sitemap:
         else:
             raise TypeError("site argument not a subclass of 'Site'.")
 
+    def unregister_site(self, method: str, path: str):
+        method = get_http_method_type(method)
+        check_relative_path(path)
+        if path[0] != "^":
+            path = "^" + path
+        if path[-1] != "$":
+            path = path + "$"
+        found = False
+        for key in self.methods[method].keys():
+            if path == key:
+                found = True  # deleting right here raises RuntimeError
+        if found:
+            del self.methods[method][key]
+            logger.set_context("registration")
+            logger.debug(
+                f"Unregistered site/function for path '{path}'")
+        else:
+            logger.warning(
+                f"Site for path '{path}' not found. Cannot be unregistered.")
+
     def get_content(self, method: str, path: str, received_data: str = ""):
         response_code = 500
         text = ""
@@ -287,12 +315,34 @@ def serves_post(path):
 
 
 def static_page(file_path, path):
+    """register static page"""
     check_relative_file_path(file_path)
     check_relative_path(path)
     site = StaticSite(path, file_path)
     _sitemap.register_site("GET", site)
 
 
+def register_get(func, path: str):
+    """register dynamic GET page (function)"""
+    check_relative_path(path)
+    if callable(func):
+        _sitemap.register_site("GET", func, path)
+
+
+def register_post(func, path: str):
+    """register dynamic POST page (function)"""
+    check_relative_path(path)
+    if callable(func):
+        _sitemap.register_site("POST", func, path)
+
+
+def unregister(method: str, path: str):
+    """unregister any page (static or dynamic)."""
+    check_relative_path(path)
+    method = get_http_method_type(method)
+    _sitemap.unregister_site(method, path)
+
+
 def start(superpath="/"):
     logger.autosave = True
     logger.header(True, True, description, version=True)
